/*
	Desc: 	Sample application for demonstrating instrumentation with JMX
	Date: 	2011.04.20.
	Author: Imre Kocsis, BME MIT
*/

package hu.bme.mit.ftsrg.jmxbeep;

import java.awt.Toolkit;
import java.lang.management.ManagementFactory;
import java.util.Date;

import javax.management.MBeanServer;
import javax.management.ObjectName;

public class JMXBeeper implements Runnable{

	protected boolean muted = false;
	protected int cycleTimeInMsec = 1000;
	protected boolean shouldExit = false;
	
	public void run() {
		while(!shouldExit){
			if(!muted) {
				// Emit beep sound.
				Toolkit.getDefaultToolkit().beep();
				// Show visual beep.
				System.out.println(new Date() + " Beep");
			}
			try {
				Thread.sleep(cycleTimeInMsec);
			} catch (InterruptedException e) {
				System.out.println("Interrupted!");
				System.exit(1);
			}
		}
	}

/**
 * Starts a JMXBeeper in a thread and registers it on the JMX interface.
 */
public static void main(String[] args){
		
		JMXBeeper beepbeep = new JMXBeeper();
		new Thread(beepbeep).start();
		
		BeeperControl bc = new BeeperControl(beepbeep);
		
		try {
			ObjectName name = null;
			name = new ObjectName("hu.bme.mit.ftsrg.beeper:type=control");
		
			MBeanServer mbs = ManagementFactory.getPlatformMBeanServer();
			
			mbs.registerMBean(bc, name);

		} catch (Exception e) {
			/*
			 * Here we may receive:
			 *   InstanceAlreadyExistsException
			 *   MBeanRegistrationException
			 *   NotCompliantMBeanException
			 *   NullPointerException
			 *   MalformedObjectNameException
			 */
			e.printStackTrace();
			System.exit(2);
		}
		
	}
}
